import { Compiler } from './compiler';
import { FloatNode, IFloatNode, Mat2Node, Mat3Node, Mat4Node, Vec2Node, Vec3Node, Vec4Node } from './types';
export declare class FloatBiFuncNode extends FloatNode {
    private readonly a;
    private readonly b;
    private readonly func;
    constructor(a: IFloatNode, b: IFloatNode, func: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class FloatPowNode extends FloatBiFuncNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatMaxNode extends FloatBiFuncNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatMinNode extends FloatBiFuncNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatDistanceNode extends FloatBiFuncNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatDotNode extends FloatBiFuncNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare function inverse<T extends Mat2Node | Mat3Node | Mat4Node>(x: T): T;
export declare function transpose<T extends Mat2Node | Mat3Node | Mat4Node>(x: T): T;
export declare function radians<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function degrees<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function sin<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function cos<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function tan<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function asin<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function acos<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function atan<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(yOverX: T): T;
export declare function length<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): FloatNode;
export declare function normalize<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function exp<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function log<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function exp2<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function log2<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function sqrt<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function inversesqrt<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function abs<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdx<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdy<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdxCoarse<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdyCoarse<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdxFine<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function dFdyFine<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function sign<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function floor<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function fract<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function ceil<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T): T;
export declare function clamp<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node, U extends T | FloatNode>(x: T, minVal: U, maxVal: U): T;
export declare function mix<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node, U extends T | FloatNode>(x: T, y: T, a: U): T;
export declare function step<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node, U extends T | FloatNode>(edge: U, x: T): T;
export declare function smoothstep<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node, U extends T | FloatNode>(edge0: U, edge1: U, x: T): T;
export declare function pow<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T, y: T): T;
export declare function max<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T, y: T): T;
export declare function min<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T, y: T): FloatNode;
export declare function dot<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T, y: T): FloatNode;
export declare function cross<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(x: T, y: T): T;
export declare function reflect<T extends Vec2Node | Vec3Node | Vec4Node>(incident: T, normal: T): T;
export declare function refract<T extends Vec2Node | Vec3Node | Vec4Node>(incident: T, normal: T, eta: FloatNode): T;
export declare function mod<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node, U extends T | FloatNode>(x: T, y: U): T;
export declare function saturate<T extends FloatNode | Vec2Node | Vec3Node | Vec4Node>(a: T): T;
