import { Compiler, CompileResult, FragmentCompiler, ShaderNode } from './compiler';
import { BaseType } from './nodes';
import { IntNode } from './types';
export declare abstract class ArrayNode<T extends ShaderNode<string>> implements ShaderNode<string> {
    readonly type: BaseType<T>;
    constructor(type: BaseType<T>);
    protected startIndex: number;
    abstract limit: IntNode | number;
    abstract compile(c: Compiler): CompileResult<string>;
    get(i: IntNode | number): T;
    protected abstract clone(): ArrayNode<T>;
    slice(start: number, end: number): ArrayNode<T>;
    first(num: number): ArrayNode<T>;
    sum<R extends ShaderNode<string> & {
        add(o: R): R;
    }>(block: (v: T, index: IntNode) => R): {
        compile(c: Compiler): {
            chunk: string;
            out: string;
        };
        add(o: R): R;
    };
    map<R extends ShaderNode<string>>(block: (v: T, index: IntNode) => R): ArrayNode<R>;
}
export declare class UniformArrayNode<T extends ShaderNode<string>> extends ArrayNode<T> {
    private readonly name;
    readonly type: BaseType<T>;
    readonly limit: IntNode | number;
    constructor(name: string, type: BaseType<T>, limit: IntNode | number);
    compile(c: Compiler): {
        pars: string;
        out: string;
    };
    protected clone(): UniformArrayNode<T>;
}
export declare class VaryingArrayNode<T extends ShaderNode<string>> extends ArrayNode<T> {
    private readonly node;
    readonly limit: number | IntNode;
    readonly type: BaseType<T>;
    constructor(node: ArrayNode<T>, limit?: number | IntNode, type?: BaseType<T>);
    compile(c: FragmentCompiler): CompileResult<string>;
    protected clone(): VaryingArrayNode<T>;
}
